pub struct DistributedVector {
pub local_values: Vec<f64>,
pub ghost_values: Vec<f64>,
pub partition: RowPartition,
pub ghost_rows: Vec<usize>,
}Expand description
A vector distributed across workers with separate local and ghost storage.
Fields
local_values: Vec<f64>Values for owned rows (length = partition.n_local()).
ghost_values: Vec<f64>Values for ghost rows (length = ghost_rows.len()).
partition: RowPartitionRow ownership metadata.
ghost_rows: Vec<usize>Global indices of the ghost rows (parallel to ghost_values).
Implementations
Sourceimpl DistributedVector
impl DistributedVector
Sourcepub fn from_global(
global: &[f64],
partition: &RowPartition,
ghost_rows: &[usize],
) -> SparseResult<Self>
pub fn from_global( global: &[f64], partition: &RowPartition, ghost_rows: &[usize], ) -> SparseResult<Self>
Construct a distributed vector by slicing the global vector.
Arguments
global— The full global vector of lengthn_global_rows.partition— Which rows this worker owns.ghost_rows— Global indices of ghost rows needed by this worker.
Sourcepub fn to_global(&self, n_global: usize) -> Vec<f64>
pub fn to_global(&self, n_global: usize) -> Vec<f64>
Assemble the full global vector (owned rows only; other entries are 0).
Sourcepub fn get_global(&self, global_row: usize) -> Option<f64>
pub fn get_global(&self, global_row: usize) -> Option<f64>
Look up a value by global row index (searches local then ghost storage).