#[non_exhaustive]pub enum PartitionMethod {
Contiguous,
RoundRobin,
GraphBased,
}Expand description
Strategy used to assign rows to workers.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Contiguous
Contiguous blocks of rows: worker i owns rows [i*n/p, (i+1)*n/p).
RoundRobin
Round-robin: row r goes to worker r % p.
GraphBased
Greedy by row NNZ: balance work by assigning rows greedily so that each worker gets approximately the same number of non-zeros.