pub struct DistributedCsr {
pub local_matrix: CsrMatrix<f64>,
pub partition: RowPartition,
pub ghost_rows: Vec<usize>,
}Expand description
A worker’s local view of a distributed CSR matrix.
local_matrix rows correspond to the global rows listed in
partition.local_rows (index 0 = partition.local_rows[0], etc.).
ghost_rows holds the global row indices of off-partition rows referenced
by at least one non-zero in the local rows.
Fields
local_matrix: CsrMatrix<f64>Local CSR matrix (only owned rows; columns are global indices).
partition: RowPartitionRow ownership information.
ghost_rows: Vec<usize>Global row indices that appear as column targets in the local rows but are owned by other workers — i.e. halo / ghost rows.