BlockCSR

Struct BlockCSR 

pub struct BlockCSR<T> {
    pub nrows: usize,
    pub ncols: usize,
    pub block_rows: usize,
    pub block_cols: usize,
    pub num_block_rows: usize,
    pub num_block_cols: usize,
    pub indptr: Vec<usize>,
    pub block_col_indices: Vec<usize>,
    pub data: Vec<T>,
}
Block Compressed Sparse Row (BCSR / BSR) format.

The matrix is divided into (r × c) blocks. Only blocks containing at least one non-zero are stored. Internally each stored block is a dense r * c array.

When to use

Use BlockCSR when the sparse pattern has a natural block structure (e.g., FEM stiffness matrices, graph problems with vector unknowns per node). Dense block kernels (GEMV) run much faster than scalar scatter operations.

Fields

nrows: usize

Matrix rows.

ncols: usize

Matrix cols.

block_rows: usize

Block row size.

block_cols: usize

Block col size.

num_block_rows: usize

Number of block rows = ceil(nrows / block_rows).

num_block_cols: usize

Number of block cols = ceil(ncols / block_cols).

indptr: Vec<usize>

CSR-like indptr over block rows; length = num_block_rows + 1.

block_col_indices: Vec<usize>

Block column indices; length = number of stored blocks.

data: Vec<T>

Dense block data; length = #blocks * block_rows * block_cols. Block k occupies data[k * block_rows * block_cols .. (k+1) * block_rows * block_cols] in row-major order.

Implementations

Source

impl<T> BlockCSR<T>

pub fn from_csr( csr: &CsrMatrix<T>, block_rows: usize, block_cols: usize, ) -> SparseResult<Self>

Build a BlockCSR from a CSR matrix with given block dimensions.

Arguments
  • csr - Source CSR matrix.
  • block_rows - Block row size (must be ≥ 1).
  • block_cols - Block col size (must be ≥ 1).
pub fn spmv(&self, x: &[T]) -> SparseResult<Vec<T>>
where T: Add<Output = T> + Mul<Output = T>,

SpMV: y = self * x.

pub fn to_csr(&self) -> SparseResult<CsrMatrix<T>>

Convert back to CSR.

pub fn num_blocks(&self) -> usize

Number of stored blocks.