pub fn sparse_identity<F>(n: usize) -> SparseResult<CsrMatrix<F>>Expand description
Create an n x n sparse identity matrix in CSR format.
pub fn sparse_identity<F>(n: usize) -> SparseResult<CsrMatrix<F>>Create an n x n sparse identity matrix in CSR format.