sparse_matrix_norm

Function sparse_matrix_norm 

pub fn sparse_matrix_norm<F>(
    a: &CsrMatrix<F>,
    norm_type: SparseNorm,
) -> SparseResult<F>
where F: Float + NumAssign + Sum + SparseElement + Debug + 'static,
Compute a matrix norm of a sparse CSR matrix.

  • One: max over columns of sum of absolute values (||A||_1)
  • Inf: max over rows of sum of absolute values (||A||_inf)
  • Frobenius: sqrt(sum(|a_ij|^2))